@@ -6,13 +6,8 @@ from tqdm import tqdm
 
 class Game:
     def __init__(self):
-        self.reset()
-        self.enemys_order = {
-            0: [1, 2, 3],
-            1: [2, 3, 0],
-            2: [3, 0, 1],
-            3: [0, 1, 2]
-        }
+        self.players = [Player(), Player(), Player(), Player()]
+        self.hist = []
         self.round = 1
         self.current_player = 0
         self.first_winner_was = -1
@@ -21,6 +16,12 @@ class Game:
         self.current_move_pieces = []
         self.current_enemys = []
         self.current_start_attempts = 0
+        self.enemys_order = {
+            0: [1, 2, 3],
+            1: [2, 3, 0],
+            2: [3, 0, 1],
+            3: [0, 1, 2]
+        }
 
     def __dice_generator(self):
         """
@@ -62,6 +63,14 @@ class Game:
         """
         self.players = [Player(), Player(), Player(), Player()]
         self.hist = []
+        self.round = 1
+        self.current_player = 0
+        self.first_winner_was = -1
+        self.current_dice = -1
+        self.observation_pending = False
+        self.current_move_pieces = []
+        self.current_enemys = []
+        self.current_start_attempts = 0
 
     def __gen_observation(self, player_idx):
         # Roll the dice
@@ -80,6 +89,9 @@ class Game:
         player_is_a_winner = player.player_winner()
         # Check if there is a winner
         there_is_a_winner = any([p.player_winner() for p in self.players])
+
+
+
         return dice, move_pieces, player_pieces, enemy_pieces, player_is_a_winner, there_is_a_winner
 
     def __set_enemy_pieces(self, player_idx, enemy_pieces):
@@ -152,7 +164,7 @@ class Game:
             pass # This line is present for readability
 
         # Check if the player now is the winner
-        if self.first_winner_was != -1 and self.players[self.current_player].player_winner():
+        if self.first_winner_was == -1 and self.players[self.current_player].player_winner():
             self.first_winner_was = self.current_player
 
         # Add the bord after the move to the history
@@ -182,6 +194,13 @@ class Game:
 
         return after_obs
 
+    def get_winner_of_game(self):
+        """
+        Returns the winner of the game
+        :return winner: If there has been a winner the winner is return if not -1 is returned
+        """
+        return self.first_winner_was + 1
+
     def get_hist(self):
         """
         Returns the history there has been recorded during the game. This history can be used to make
